"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var postcss_1 = __importDefault(require("postcss"));
var rtlcss_1 = __importDefault(require("rtlcss"));
var _types_1 = require("../@types");
var _constants_1 = require("../constants");
var comments_1 = require("../utilities/comments");
var selectors_1 = require("../utilities/selectors");
var options_1 = require("../utilities/options");
exports.insertCombinedRules = function (appends, rule, options) {
    var ltrPrefix = options.ltrPrefix, rtlPrefix = options.rtlPrefix, source = options.source, processUrls = options.processUrls, useCalc = options.useCalc, stringMap = options.stringMap;
    var ruleStr = rule.toString();
    var ruleFlippedtring = rtlcss_1.default.process(ruleStr, {
        clean: false,
        processUrls: processUrls,
        useCalc: useCalc,
        stringMap: options_1.getRTLCSSStringMap(stringMap)
    });
    if (ruleStr === ruleFlippedtring) {
        comments_1.removeRTLComments(rule);
        return;
    }
    var root = postcss_1.default.parse(ruleFlippedtring);
    var ruleFlipped = root.first;
    var deleteDeclarations = [];
    var ruleFlippedSecond = ruleFlipped.clone();
    var index = 0;
    ruleFlipped.walk(function (nodeFlipped) {
        if (nodeFlipped.type === _constants_1.DECLARATION_TYPE) {
            var decl = rule.nodes[index];
            var declStr = decl.toString();
            var declFlippedStr = nodeFlipped.toString();
            var nodeFlippedSecond = ruleFlippedSecond.nodes[index];
            if (declStr === declFlippedStr) {
                deleteDeclarations.push(nodeFlipped);
                deleteDeclarations.push(nodeFlippedSecond);
            }
            else {
                nodeFlipped.replaceWith(decl.clone());
                deleteDeclarations.push(decl);
            }
        }
        index++;
    });
    deleteDeclarations.forEach(function (decl) {
        var prev = decl.prev();
        if (prev && prev.type === _constants_1.COMMENT_TYPE) {
            prev.remove();
        }
        decl.remove();
    });
    selectors_1.addSelectorPrefixes(ruleFlipped, source === _types_1.Source.ltr ? ltrPrefix : rtlPrefix);
    selectors_1.addSelectorPrefixes(ruleFlippedSecond, source === _types_1.Source.rtl ? ltrPrefix : rtlPrefix);
    comments_1.removeRTLComments(rule);
    comments_1.removeRTLComments(ruleFlipped);
    comments_1.removeRTLComments(ruleFlippedSecond);
    appends.push({
        rule: rule,
        ruleLTR: ruleFlipped,
        ruleRTL: ruleFlippedSecond
    });
};
